import { Component, OnInit } from '@angular/core';
import { Location } from '@angular/common';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Router, ActivatedRoute } from '@angular/router';
// 网络请求
import { HttpService } from '../../../share/http/http';
import { NzMessageService } from 'ng-zorro-antd/message';

@Component({
  selector: 'app-info',
  templateUrl: './info.component.html',
  styleUrls: ['./info.component.less'],
})
export class RealnameInfoComponent implements OnInit {
  constructor(
    private fb: FormBuilder,
    private http: HttpService,
    private router: Router,
    private route: ActivatedRoute,
    private location: Location,
    private message: NzMessageService
  ) {}

  // 文章ID
  Id = '';
  // 文章信息
  info!: FormGroup;
  // 文章图片数组
  imageArray = [];
  // 视频数组
  videoArray = [];
  // 是否显示弹窗
  isVisible = false;
  // 备注信息
  remarks = '';

  ngOnInit(): void {
    this.info = this.fb.group({
      content: ['', [Validators.required]],
      url: ['', [Validators.required]],
      images: ['', [Validators.required]],
      reason: ['', [Validators.required]],
      status: [1, [Validators.required]],
      videos: ['', [Validators.required]],
    });
    this.Id = this.route.snapshot.params.id;
    this.getData();
  }

  // 获取文章详情
  getData() {
    this.http
      .get('/api/admin/roleinfo', { role_id: this.Id })
      .then((res: any) => {
        if (res.code === 1) {
          this.setValue(res.data);
        }
      });
  }

  // 设置文章初始值
  setValue(info: any) {
    this.info = this.fb.group({
      id: [info.id],
      content: [info.content, [Validators.required]],
      reason: [info.reason, [Validators.required]],
      images: [info.images, [Validators.required]],
      videos: [info.videos, [Validators.required]],
      status: [info.status, [Validators.required]],
    });
    this.imageArray = info.images.split(',');
    this.videoArray = info.videos.split(',');
  }

  // 提交数据
  submitForm() {
    this.info.patchValue({ images: this.imageArray.toString() });
    for (const i in this.info.controls) {
      if (this.info.controls.hasOwnProperty(i)) {
        this.info.controls[i].markAsDirty();
        this.info.controls[i].updateValueAndValidity();
      }
    }
    if (this.info.status === 'INVALID') {
      console.log('验证不通过');
    } else {
      this.http
        .post('/api/article/update', this.info.value)
        .then((res: any) => {
          console.log(res);
          if (res.code === 1) {
            this.message.success(res.msg);
            this.getData();
          }
        });
    }
  }

  // 点击返回
  back() {
    this.location.back();
  }

  // 取消输入备注
  handleCancel() {
    this.isVisible = false;
    this.remarks = '';
  }

  // 输入备注确定
  handleOk() {
    this.http
      .post('/api/admin/updaterole', {
        role_id: this.Id,
        remarks: this.remarks,
        status:3
      })
      .then((res: any) => {
        console.log(res);
        if (res.code === 1) {
          this.isVisible = false;
          this.remarks = '';
          this.message.success(res.msg);
          this.getData();
        }
      });
  }

  // 点击通过
  pass(){
    console.log(1111);
    
    this.http
    .post('/api/admin/updaterole', {
      role_id: this.Id,
      status:2
    })
    .then((res: any) => {
      if (res.code === 1) {
        this.message.success(res.msg);
        this.getData();
      }
    });
  }
}
