import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterModule, Routes } from '@angular/router';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';

// 公共ui组件
import { ZrrorUi } from '../share/zrror-ui/zrror-ui';
// 布局组件
import { LayoutPcComponent } from '../layout/layout-pc/layout-pc.component';
import { LayoutPcLoginComponent } from '../layout/layout-pc-login/layout-pc-login.component';

// pc 组件
import { PcHomeComponent } from './pc-home/pc-home.component';
import { PcArticleComponent } from './pc-article/pc-article.component';
import { ArticleInfoComponent } from './pc-article/info/info.component';
import { RealnameInfoComponent } from './pc-realname/info/info.component';
import { OrderInfoComponent } from './pc-order/info/info.component';
import { PcTopicComponent } from './pc-topic/pc-topic.component';
import { PcOrderComponent } from './pc-order/pc-order.component';
import { PcRealnameComponent } from './pc-realname/pc-realname.component';

import { UploadComponent } from '../component/upload/upload.component';

// antd mobile
import { NgZorroAntdMobileModule } from 'ng-zorro-antd-mobile';

// 路由守卫
import { AuthGuard } from '../share/canactivate/auth.guard';
import { AuthAllGuard } from '../share/canactivate/auth-all.guard';

const routes: Routes = [
  {
    path: '',
    component: LayoutPcLoginComponent,
    canActivate: [AuthGuard],
  },
  {
    path: 'pc',
    component: LayoutPcComponent,
    canActivate: [AuthAllGuard],
    children: [
      {
        path: '',
        component: PcHomeComponent,
      },
      {
        path: 'topic',
        component: PcTopicComponent,
      },
      {
        path: 'article',
        component: PcArticleComponent,
      },
      {
        path: 'article/info/:id',
        component: ArticleInfoComponent,
      },
      {
        path: 'order',
        component: PcOrderComponent,
      },
      {
        path: 'order/info/:id',
        component: OrderInfoComponent,
      },
      {
        path: 'realname',
        component: PcRealnameComponent,
      }, 
      {
        path: 'realname/info/:id',
        component: RealnameInfoComponent,
      },

      // {
      //   path: 'role',
      //   loadChildren:()=>import('./pc-role/pc-role.module').then(mod=>mod.PcRoleModule)
      // },
    ],
  },
];

@NgModule({
  declarations: [
    LayoutPcComponent,
    LayoutPcLoginComponent,
    PcHomeComponent,
    PcArticleComponent,
    ArticleInfoComponent,
    RealnameInfoComponent,
    OrderInfoComponent,
    UploadComponent,
    PcTopicComponent,
    PcOrderComponent,
    PcRealnameComponent,
  ],
  imports: [
    CommonModule,
    RouterModule.forChild(routes),
    NgZorroAntdMobileModule,
    // 表单组件
    FormsModule,
    ReactiveFormsModule,
    ...ZrrorUi.uiArr,
  ],
  exports: [RouterModule],
})
export class RoutesRoutingModule {}
